@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004, 2005 Marcus Glocker <marcus@nazgul.ch>
+ * Copyright (c) 2004, 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -15,42 +15,48 @@
  */
 
 /*
- * You can tune nostromo with this parameters. Please do just change
- * this parameters if you fully understand them. Wrong parameters can
+ * You can tune nostromo with this parameters.  Please do just change
+ * this parameters if you fully understand them.  Wrong parameters can
  * cause server crashs or bad performance.
  */
 
 /*
- * Maximal concurrent connections
+ * maximal concurrent connections
  */
 #define CON	1024
 
 /*
- * Maximal Header Numbers we receive at once
+ * maximal request headers we receive at once
  */
 #define HDN	16
 
 /*
- * Maximal Header Size (bytes)
+ * maximal header size (bytes)
  */
 #define HDS	8192
 
 /*
- * Maximal Block Size we send data to client (bytes)
+ * maximal block size we send data to client (bytes)
  */
 #define BS	8192
 
 /*
- * Network Session Timeout: client->server (seconds)
+ * socket send buffer size (bytes), 0 = keep operating system default
+ */ 
+#define SBS	0
+
+/*
+ * network session timeout: client<->server (seconds)
  */
 #define TON	15
 
 /*
- * CGI Session Timeout: cgi->server (seconds)
+ * CGI session timeout: cgi<->server (seconds)
  */
 #define TOC	60
 
 /*
- * Default server port
+ * default server ports
  */
 #define PRT	80
+#define PRTS	443
