@@ -888,15 +888,19 @@ http_cgi_header(char *header_cgi, char *status, const int dsize1,
  * 	0 = headers not complete, 1 = headers complete
  */
 int
-http_header_comp(char *header)
+http_header_comp(char *header, const int len)
 {
 	int	r;
 	char	*p, *end;
 
 	r = 0;
 
+	/* check header for minimum size */
+	if (len < 4)
+		return (0);
+
 	/* post */
-	if (!strncasecmp("POST ", header, 5)) {
+	if (!strncasecmp("POST", header, 4)) {
 		p = header;
 		if ((p = strstr(p, "\r\n\r\n")) == NULL)
 			return (0);
@@ -905,7 +909,7 @@ http_header_comp(char *header)
 	}
 
 	/* any header */
-	end = header + (strlen(header) - 4);
+	end = header + (len - 4);
 	if (!strcmp(end, "\r\n\r\n"))
 		r = 1;
 
