@@ -102,7 +102,7 @@ const char *http_fn_auw		= "WWW-Authenticate:";
 const char *http_fn_ran		= "Range:";
 const char *http_fn_rac		= "Content-Range:";
 const char *http_fn_aen		= "Accept-Encoding:";
-const char *http_fv_srv		= "nostromo 1.7.8";
+const char *http_fv_srv		= "nostromo 1.7.9";
 const char *http_fv_pro		= "HTTP/1.1";
 const char *http_fv_cgi		= "CGI/1.1";
 const char *http_fv_teg		= "chunked";
@@ -1162,7 +1162,7 @@ main(int argc, char *argv[])
 			c[sdnow].to = time(&tnow);
 
 			/* we need a full header sequence */
-			size = http_header_comp(c[sdnow].rbuf);
+			size = http_header_comp(c[sdnow].rbuf, c[sdnow].roff);
 			if (!size)
 				continue;
 
